% This is the main controlling part of public charging load modeling, 
% it accepts vehicle specifications, and calls the relevant functions
% to complete the modeling the load profile
%**************************************************************************
% Notice: the number of vehicles being charged in the station can be
% specified within "PopularTimes_ServiceStations.csv" file. As an example 
% it has been initialised with 50 for both stations.
%**************************************************************************
clc; clear;close all;
%**************************************************************************
%% loads the Poular Times, number of chrging points and the number vehicles to be
%% charged at the station by calling "FuncPopularTimes" function
%% Hollies Filling  (24-Hours) Station: SheetNumber=1 
%% For Oban Filling (12-Hours) Station: SheetNumber=2
%% Given the differences in weekday attendance time distribution, as noted in lines 
%% 20 and 21, there is the flexibility to choose the specific day of the week for simulating its demand.
%%*************************************************************************
SheetNumber=2;                            %  place where data of the target charging station is located
[VehiclesPerHour, TotalVehiclesPerDay]=FuncVehicleAttendance(SheetNumber);
FileName = sprintf('FleetLoadProfile_%s.xlsx', datestr(now,'yyyy-mm-dd_HH-MM')); % creates the file where the results are stored
writematrix('Vehicles Per Hour',FileName,'Sheet',4,'Range','A1'); % Writes the header for the data on the relevent column
writematrix((VehiclesPerHour),FileName,'Sheet',4,'Range','A2');   % Writes the data for the data on the relevent column
%%********************************Vehicle Specifications*********************************
FleetSize=TotalVehiclesPerDay;                   % number of the vehicles served by the station
BatteryCapacity = 400;                           % battery capacity [kWh]
SpecificConsumption   = 1.8;                     % specific energy consumption[kWh/Mile]
%%*******************************Charger Specifications **********************************
ChargingPower = 350;                             % power rating of the charger[kW];
EffCharger = 1;                                  % charger effciciency
%%*********Gets the traveled distanaces ***
FleetTravel= FuncTraveledDistance(FleetSize);                     % "FuncTraveledDistance" will return the vehicls's traveled distance
%%***************Gets SoC of the vehiles (arriving at the station)*************************
VehiclesStateOfCharge = FuncVehiclesStateOfCharge(BatteryCapacity,SpecificConsumption,FleetTravel); 
writematrix('State of Charge',FileName,'Sheet',3,'Range','A1');          % Writes the header for the data on the relevent column
writematrix((VehiclesStateOfCharge),FileName,'Sheet',3,'Range','A2') ;   % Writes the header for the data on the relevent column
%%*********************** Calls Vehcile Charging Function  ********************************
TotalPower=0;
VehcileCounter=0;
for i=1:numel(VehiclesPerHour)            % "VehiclesPerHour" is the number of vehicles served hourly  
    VehicleSetNumber= VehiclesPerHour(i);
if VehicleSetNumber==0
else   
for Vehicle=1:VehicleSetNumber
    VehcileCounter=VehcileCounter+1;
    VehicleName = strcat( 'Vehicle_',num2str(VehcileCounter) );
    
    Alphabet = reshape('A':'Z',[],1);
    Column = num2cell(Alphabet(1+rem(VehcileCounter-1,26)));
    v = fix((VehcileCounter-1)/26);
    while any(v), Column(v>0) = strcat(Alphabet(1+rem(v(v>0)-1,26)),Column(v>0)); v = fix((v-1)/26); end
    Column=Column{1}    
    writematrix(VehicleName,FileName,'Sheet',1,'Range',[Column,num2str(1)]); % Writes the header for the data on the relevent column   
    SOC=VehiclesStateOfCharge(VehcileCounter);
    StartTime=(i-1)*3600+2;
    EndTime=48*3600;           % for time frame 
    [VehicleLoadXaxis, VehicleLoad]=FuncVehicleCharging(FileName,Column,BatteryCapacity, ChargingPower,EffCharger, SOC, StartTime, EndTime);
    TotalPower=TotalPower+VehicleLoad;
end
end
writematrix('Demand',FileName,'Sheet',2,'Range','A1');   % Writes the header for the data on the relevent column
writematrix(TotalPower,FileName,'Sheet',2,'Range','A2'); % Writes the data on the relevent column
end
%%*********Call average demand calculating fucntion ********************
AveragingWindow= 'Hourly';    % 60 min
FuncAveragingDemand(FileName,AveragingWindow); % calling averaging function
%%**********************************************************************
figure ()
Pt1=plot(VehicleLoadXaxis, TotalPower,'blue','linewidth',2.4);
xlabel('Time (hr)');
ylabel('Demand (kW)');
legend('Power demand','Location','northwest');
%%**********************************************************************